@@ -23,9 +23,9 @@ foreach my $type (__PACKAGE__->available_method_types)
 
 sub type { 'integer' }
 
-sub perl_column_defintion_attributes
+sub perl_column_definition_attributes
 {
-  grep { $_ ne 'length' } shift->SUPER::perl_column_defintion_attributes;
+  grep { $_ ne 'length' } shift->SUPER::perl_column_definition_attributes;
 }
 
 1;
