@@ -9,6 +9,28 @@ our $VERSION = '0.68';
 
 sub type { 'one to one' }
 
+sub requires_preexisting_parent_object
+{
+  my($self) = shift;
+
+  my $meta   = $self->parent;
+  my $f_meta = $self->class->meta;
+
+  my $column_map = $self->column_map;
+  my %pk = map { $_ => 1 } $meta->primary_key_column_names;
+
+
+  foreach my $local_column (keys %$column_map)
+  {
+    if($pk{$local_column})
+    {
+      return $self->{'requires_preexisting_parent_object'} = 1;
+    }
+  }
+
+  return $self->{'requires_preexisting_parent_object'} = 0;
+}
+
 1;
 
 __END__
@@ -73,6 +95,10 @@ Get or set the default list of L<auto_method_types|Rose::DB::Object::Metadata::R
 
 =over 4
 
+=item B<column_map [HASH | HASHREF]>
+
+Get or set a reference to a hash that maps local column names to foreign column names.
+
 =item B<build_method_name_for_type TYPE>
 
 Return a method name for the relationship method type TYPE.  
@@ -93,17 +119,15 @@ One to one relationships encapsulate essentially the same information as foreign
 
 If passed a local column name LOCAL, return the corresponding column name in the foreign table.  If passed both a local column name LOCAL and a foreign column name FOREIGN, set the local/foreign mapping and return the foreign column name.
 
-=item B<column_map [HASH | HASHREF]>
+=item B<optional [BOOL]>
 
-Get or set a reference to a hash that maps local column names to foreign column names.
+This method is the mirror image of the L<required|/required> method.   Passing a true value to this method is the same thing as setting L<required|/required> to false, and vice versa.  Similarly, the return value is the logical negation of L<required|/required>.
 
-=item B<referential_integrity [BOOL]>
+=item B<required [BOOL]>
 
-Get or set the boolean value that determines what happens when the columns in the L<column_map|/column_map> have L<defined|perlfunc/defined> values, but the object they point to is not found.  If true, a fatal error will occur.  If false, then the methods that service this relationship will simply return undef.  The default is true.
+Get or set the boolean value that determines what happens when the local columns in the L<column_map|/column_map> have L<defined|perlfunc/defined> values, but the object they relate to is not found.  If true, a fatal error will occur when the methods that fetch objects through this relationship are called.  If false, then the methods will simply return undef.
 
-=item B<soft [BOOL]>
-
-This method is the mirror image of the L<referential_integrity|/referential_integrity> method.   Passing a true is the same thing as setting L<referential_integrity|/referential_integrity> to false, and vice versa.  Similarly, the return value is the logical negation of L<referential_integrity|/referential_integrity>.
+The default is false if one or more of the local columns L<allow null values|Rose::DB::Object::Metadata::Column/not_null> or if the local columns in the column map are the same as the L<primary key columns|Rose::DB::Object::Metadata/primary_key_columns>, true otherwise.
 
 =item B<type>
 
